@@ -13,6 +13,12 @@ class LimitOrder(BaseOrder):
   timeInForce: TimeInForce
   icebergQty: NotRequired[str]
 
+class LimitMakerOrder(BaseOrder):
+  type: Literal['LIMIT_MAKER']
+  quantity: str
+  price: str
+  icebergQty: NotRequired[str]
+
 class MarketOrder(BaseOrder):
   type: Literal['MARKET']
   quantity: str
@@ -23,4 +29,4 @@ class MarketOrderQuote(BaseOrder):
   quoteOrderQty: str
   timeInForce: NotRequired[TimeInForce]
 
-Order = LimitOrder | MarketOrder | MarketOrderQuote
+Order = LimitOrder | MarketOrder | MarketOrderQuote | LimitMakerOrder
