@@ -1,12 +1,26 @@
 from typing_extensions import AsyncIterable, Generic, TypeVar
 from dataclasses import dataclass, field
 from datetime import datetime
-import json
 from decimal import Decimal, ROUND_HALF_DOWN, ROUND_FLOOR
+import json
+import orjson
+from pydantic import BaseModel, ValidationError
 from urllib.parse import quote
 from haskellian import ManagedAsync
+from binance.types import Error, ErrorRoot
 
 T = TypeVar('T')
+M = TypeVar('M', bound=BaseModel)
+
+def validate_response(r: str, Model: type[M]) -> M | Error:
+  obj = orjson.loads(r)
+  try:
+    if 'code' in obj:
+      return ErrorRoot.model_validate(obj).root
+    return Model.model_validate(obj)
+  except ValidationError as e:
+    print('Error validating:', obj)
+    raise e
 
 def binance_timestamp(dt: datetime) -> int:
   return int(1e3*dt.timestamp())
